@@ -762,7 +762,7 @@ gboolean gok_editor_save_keyboard (GokKeyboard* pKeyboard, gchar* Filename)
 				typeKey = "settings";
 				break;
 				
-			case KEYTYPE_BRANCHEDITTEXT:
+			case KEYTYPE_BRANCHCOMPOSE:
 				typeKey = "branchEditText";
 				break;
 				
