@@ -841,7 +841,7 @@ void gok_keyboard_set_accessible (GokKeyboard* pKeyboard, Accessible* pAccessibl
 		{
 			gok_spy_accessible_unref(pKeyboard->pAccessible);
 			gok_spy_accessible_ref (pAccessible);
-			gok_log("settting keyboard accessible with address: [%d]",pAccessible);
+			gok_log("setting keyboard accessible with address: [%#x]",pAccessible);
 			pKeyboard->pAccessible = pAccessible;
 		}
 		else
@@ -852,7 +852,7 @@ void gok_keyboard_set_accessible (GokKeyboard* pKeyboard, Accessible* pAccessibl
 	}
 	else
 	{
-		gok_log("settting keyboard accessible with address: [%d]",pAccessible);
+		gok_log("setting keyboard accessible with address: [%#x]",pAccessible);
 		pKeyboard->pAccessible = pAccessible;
 		gok_spy_accessible_ref(pAccessible);
 	}	
@@ -1655,9 +1655,9 @@ gboolean gok_keyboard_branch_byKey (GokKey* pKey)
 			}
 			return is_branched;
 			break;
-	        case KEYTYPE_BRANCHHYPERTEXT:
-			fprintf (stderr, "HYPERTEXT!\n");
-                        break;
+		case KEYTYPE_BRANCHHYPERTEXT:
+		fprintf (stderr, "HYPERTEXT!\n");
+			break;
 		default:
 			/* should not be here */
 			gok_log ("Unknown branch type");
@@ -1731,7 +1731,7 @@ gboolean gok_keyboard_update_dynamic (GokKeyboard* pKeyboard)
 	else
 	{
 #endif
-	gok_log("calling get list with accessible [%d] and role [%s]", 
+	gok_log("calling get list with accessible [%#x] and role [%s]", 
 		pKeyboard->pAccessible, AccessibleRole_getName(pKeyboard->search_role));
 	/* create new keys for the keyboard */
 
@@ -2039,6 +2039,13 @@ gboolean gok_keyboard_branch_gui_actions (AccessibleNode* pNodeAccessible)
 		{
 			gok_log_x("Abort action. Branching to child(ren)!");
 			gok_log_leave();
+			if (gok_spy_is_menu_role (m_InterestingRole[i]))
+			{
+				gok_log("a submenu exists...");
+				return gok_keyboard_branch_gui(pNodeAccessible, 
+										   GOK_SPY_SEARCH_MENU,
+										   SPI_ROLE_MENU); 
+			}
 			return gok_keyboard_branch_gui(pNodeAccessible, 
 						       GOK_SPY_SEARCH_ROLE,
 						       m_InterestingRole[i]);
@@ -2049,15 +2056,12 @@ gboolean gok_keyboard_branch_gui_actions (AccessibleNode* pNodeAccessible)
 	/* possible TODO: build a keyboard if more than one action available 
 	(and do this before above branch to children!)*/
 	paaction = Accessible_getAction(pNodeAccessible->paccessible);
-	gok_spy_accessible_implicit_ref(paaction);
 	if (paaction != NULL)
 	{
-		/* for now just perform the first action 
-		*** warning repeated code block*/
-		{
-		Accessible_isAction(paaction);
-		AccessibleAction_doAction(paaction, 0);
-		gok_spy_accessible_unref(paaction);
+		/* for now just perform the first action */
+		if (Accessible_isAction(paaction)) {
+			AccessibleAction_doAction(paaction, 0);
+			AccessibleAction_unref (paaction);
 		}
 
 		/* no interesting children roles found so now branch back to most 
@@ -3003,6 +3007,8 @@ gboolean gok_keyboard_validate_dynamic_keys (Accessible* pAccessibleForeground)
 		gok_log_leave();
 		return bChanged;
 	}
+	
+	/* FIXME - optimize here & in gok-spy -currently too many GUI tree searches.
 
 	/* enable/disable the branch keys */
 	pKey = pKeyboard->pKeyFirst;
