@@ -24,6 +24,7 @@
 #endif
 
 #include <dirent.h>
+#include <gconf/gconf-client.h>
 #include "gok-scanner.h"
 #include "gok-data.h"
 #include "gok-log.h"
@@ -31,6 +32,7 @@
 #include "gok-feedback.h"
 #include "gok-keyboard.h"
 #include "gok-gconf-keys.h" /* used only for uses_corepointer hack below */
+#include "gok-gconf.h" 
 #include "main.h"
 #include "gok-repeat.h"
 
@@ -119,12 +121,13 @@ static GokScannerEffect* m_pEffectsOnDwell;
 #define MAX_HANDLERS 30
 
 /* number of possible calls */
-#define MAX_CALL_NAMES 60
+#define MAX_CALL_NAMES 61
 
 /* names of all the possible effect calls */
 /* This must be in the same order as the enum "CallIds" */
 static gchar ArrayCallNames[MAX_CALL_NAMES][24] ={
-"ChunkerReset", "ChunkerChunkRows", "ChunkerChunkColumns", 
+"ChunkerReset", "ChunkerChunkNone", "ChunkerChunkRows", 
+"ChunkerChunkColumns", 
 "ChunkerNextChunk", "ChunkerPreviousChunk", 
 "ChunkerNextKey", "ChunkerPreviousKey", 
 "ChunkerKeyUp", 
@@ -171,7 +174,6 @@ gok_scanner_get_lang (void)
 		/* strip suffixes, etc. */
 		if (lang) 
 			strings = g_strsplit (lang, ".", 2);
-		g_free (lang);
 		if (strings && strings[1]) 
 			g_free (strings[1]);
 		if (strings && strings[0]) {
@@ -179,12 +181,11 @@ gok_scanner_get_lang (void)
 			strings = g_strsplit (lang, "@", 2);
 			if (strings[1]) 
 				g_free (strings[1]);
-			gok_lang = strings[0];
+			gok_lang = (unsigned char *)strings[0];
 		}
 		else
-			gok_lang = "";
+			gok_lang = (unsigned char *)"";
 	}
-	fprintf (stderr, "gok_lang=%s\n", gok_lang);
 	return gok_lang;
 }
 
@@ -211,7 +212,7 @@ gok_scanner_find_node (xmlNode *pNode, const xmlChar* name, const xmlChar* targe
 		       xmlChar **node_lang)
 {
 	xmlNode *retval = NULL;
-	int      target_lang_len = strlen (target_lang);
+	int      target_lang_len = strlen ((char *)target_lang);
 	gboolean lang_is_matched = FALSE;	
 
 	/* loop through the document looking for the name string */
@@ -493,17 +494,28 @@ gboolean gok_scanner_read_access_method (gchar* Filename)
 
 	/* get the display name of the access method */
 	pStringAttributeValue = xmlGetProp (pNodeAccessmethod, (const xmlChar *) "displayname");
-	if (pStringAttributeValue != NULL)
+	if (pStringAttributeValue == NULL)
 	{
-		strcpy (pAccessMethod->DisplayName, (gchar *)pStringAttributeValue);
-	}
-	else
-	{
-		/* use the name if no display name */
-		gok_log_x ("No display name for this access method (%s).\n", pAccessMethod->Name);
-		xmlFreeDoc (pDoc);
-		return FALSE;
+		gok_log_x ("No display name for this access method (%s).", 
+			pAccessMethod->Name);
+		/* hack to fix intltool xml translation bug */
+		pStringAttributeValue = xmlGetProp (pNodeAccessmethod, 
+			(const xmlChar *) "_displayname");
+		if (pStringAttributeValue == NULL)
+		{
+			gok_log_x ("using name: %s.", 
+				pStringAttributeValue);
+			/* use the name if no display name */
+			pStringAttributeValue = pAccessMethod->Name;
+		}
+		else
+		{
+			gok_log_x ("using _display name: %s.", 
+				pStringAttributeValue);
+		}
 	}
+		
+	strcpy (pAccessMethod->DisplayName, (gchar *)pStringAttributeValue);
 
 	/* read the UI for the access method */
 	gok_scanner_read_description (pDoc, pNodeRoot->xmlChildrenNode, pAccessMethod);
@@ -943,14 +955,19 @@ gboolean gok_scanner_read_description (xmlDoc* pDoc, xmlNode* pNode, GokAccessMe
 	g_assert (pNode != NULL);
 	g_assert (pAccessMethod != NULL);
 
+	gok_log_enter();
+	
 	if (pNode = gok_scanner_find_node (pNode, (const xmlChar *) "description", gok_scanner_get_lang (),
 					   NULL)) {
 		pStringDescription = xmlNodeListGetString (pDoc, pNode->xmlChildrenNode, 1);
 		strncpy (pAccessMethod->Description, (gchar *)pStringDescription, MAX_DESCRIPTION_TEXT);
+		gok_log ("read access method description: [%s]", pStringDescription);
 		g_free (pStringDescription);
+		gok_log_leave();
 		return TRUE;
 	}
 	else {
+		gok_log_leave();
 		return FALSE;
 	}
 }
@@ -1311,6 +1328,7 @@ GokScannerEffect* gok_scanner_read_effects (xmlNode* pNodeGiven, GokAccessMethod
 
 						/* call name */
 						pName = (char *)xmlGetProp (pNodeEffect, (const xmlChar *) "name");
+
 #if 0
 						pStringAttributeValue = xmlGetProp (pNodeEffect, (const xmlChar *) "name");
 						if (pStringAttributeValue != NULL)
@@ -1698,13 +1716,13 @@ gboolean gok_scanner_change_method (gchar* NameAccessMethod)
 
 			/* set the current access method as this one */
 			m_pAccessMethodCurrent = pAccessMethod;
+			
+			/* store the name of the access method */
+			gok_data_set_name_accessmethod (pAccessMethod->Name);
 
 			/* reset the access method */
 			gok_scanner_reset_access_method();
 
-			/* store the name of the access method so it gets saved to disk */
-			gok_data_set_name_accessmethod (pAccessMethod->Name);
-
 			return TRUE;
 		}
 		else
@@ -2505,11 +2523,15 @@ void gok_scanner_perform_effects (GokScannerEffect* pEffect)
 	/* perform the handler effect */
 	while (pEffect != NULL)
 	{
-		gok_log("looking at effect: [%s]",pEffect->pName);
+		gok_log("looking at effect: [%s]",ArrayCallNames[pEffect->CallId]);
 		EffectCodeReturned = 0;
 
 		switch (pEffect->CallId)
 		{
+			case CALL_CHUNKER_CHUNK_NONE:
+				EffectCodeReturned = gok_chunker_chunk_none ();
+				break;
+
 			case CALL_CHUNKER_CHUNK_ROWS:
 				if (gok_data_get_setting (pAccessMethod->Name, pEffect->CallParam1, 
 											&param1Rate, NULL) == TRUE)
